@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, List
 
 from pydantic import parse_obj_as
 
@@ -13,7 +13,7 @@ class LeagueExpApiV4(RiotGamesApiBase):
             tier: str,
             division: str,
             platform: Optional[str] = None
-    ) -> list[LeagueEntryDto]:
+    ) -> List[LeagueEntryDto]:
         data = self._request(f"/lol/league-exp/v4/entries/{queue}/{tier}/{division}", platform)
 
-        return parse_obj_as(list[LeagueEntryDto], data)
+        return parse_obj_as(List[LeagueEntryDto], data)
